import { _ as _applyDecoratedDescriptor, a as _initializerDefineProperty } from '../_rollupPluginBabelHelpers-7db585ca.js';
import dayjs from 'dayjs';
import { isPresent, isEqual } from '@ember/utils';
import Service from '@ember/service';
import { assert } from '@ember/debug';
import { tracked } from '@glimmer/tracking';

var _class, _descriptor;
let DayjsService = (_class = class DayjsService extends Service {
  constructor(...args) {
    super(...args);

    _initializerDefineProperty(this, "locale", _descriptor, this);
  }

  get self() {
    return dayjs;
  }

  async setLocale(locale) {
    await this.useLocale(locale);
    this.locale = locale;
  }

  async useLocale(locale) {
    assert('Locale cannot be null.', isPresent(locale));
    const localeName = locale.toLowerCase();

    if (isEqual(localeName, 'en')) {
      return;
    }

    try {
      const importedLocale = await import(`dayjs/locale/${localeName}.js`);
      assert(`${localeName} locale not found. Please make sure you typed the locale name correctly.`, isPresent(importedLocale));
    } catch {
      throw new Error(`${localeName} locale not found. Please make sure you typed the locale name correctly.`);
    }
  }

  async setTimeZone(timeZone) {
    await this.extend('timezone');
    this.self.tz.setDefault(timeZone);
  }

  async resetTimezone() {
    await this.setTimeZone();
  }

  async extend(plugin) {
    assert('Plugin name cannot be null.', isPresent(plugin));

    try {
      const importedPlugin = await import(`dayjs/plugin/${plugin}`);
      assert(`${plugin} plugin not found. Please make sure you typed the plugin name correctly.`, isPresent(importedPlugin));
      this.self.extend(importedPlugin);
    } catch {
      throw new Error(`${plugin} plugin not found. Please make sure you typed the plugin name correctly.`);
    }
  }

}, (_descriptor = _applyDecoratedDescriptor(_class.prototype, "locale", [tracked], {
  configurable: true,
  enumerable: true,
  writable: true,
  initializer: function () {
    return 'en';
  }
})), _class);

export { DayjsService as default };
